# Spectral Graph Wavelet Tools

Extended tools for [PyGSP](https://github.com/epfl-lts2/pygsp). Includes:
 - [GraphWave](https://arxiv.org/abs/1710.10321)
 - [Spectral Graph Wavelet Signature](https://arxiv.org/abs/1705.06250)
 - Heat Kernel Centrality
 - Spectrogram
